@@ -1,18 +1,18 @@
 
 /*
  * This file contains declarations to interface R with Akimas
- * triangulation package from ACMs Collected Algorithms Archive.
+ * interpolation packages from ACMs Collected Algorithms Archive.
  *
  * The ACM copyright of the original Fortran code is described at
- *   http://www.acm.org/pubs/copyright_policy/softwareCRnotice.html
+ *   http://www.acm.org/publications/policies/software-copyright-notice
+ *
+ * This interface layer is copyright by
  *
- * This interface layer is copyright by 
- * 
  *   Albrecht Gebhardt <albrecht.gebhardt@uni-klu.ac.at>
- * 
+ *
  * and can be used under both GPL or ACM license to be conform
  * with the restrictions in the above mentioned ACM license.
- * 
+ *
  */
 
 #include <R.h>
@@ -24,6 +24,7 @@
 
 /* Fortran interface descriptions: */
 
+/* ACM 760: */
 static R_NativePrimitiveArgType rgbi3p_t[12] = {
   INTSXP,  /* MD,     */
   INTSXP,  /* NXP,    */
@@ -39,23 +40,8 @@ static R_NativePrimitiveArgType rgbi3p_t[12] = {
   REALSXP  /* WK,     */
 };
 
-static R_NativePrimitiveArgType idbvip_t[13] = {
-  INTSXP,  /* MD,   */
-  INTSXP,  /* NCP,  */
-  INTSXP,  /* NDP,  */
-  REALSXP, /* XD,   */
-  REALSXP, /* YD,   */
-  REALSXP, /* ZD,   */
-  INTSXP,  /* NIP,  */
-  REALSXP, /* XI,   */
-  REALSXP, /* YI,   */
-  REALSXP, /* ZI,   */
-  INTSXP,  /* IWK,  */
-  REALSXP, /* WK,   */
-  LGLSXP   /* MISSI */
-};
-
-static R_NativePrimitiveArgType sdbi3p_t[16] = {
+/* ACM 761: */
+static R_NativePrimitiveArgType sdbi3p_t[17] = {
   INTSXP,  /* MD,     */
   INTSXP,  /* NDP,    */
   REALSXP, /* XD,     */
@@ -71,27 +57,11 @@ static R_NativePrimitiveArgType sdbi3p_t[16] = {
   LGLSXP,  /* EXTRPI, */
   INTSXP,  /* NEAR,   */
   INTSXP,  /* NEXT,   */
-  REALSXP  /* DIST    */
+  REALSXP, /* DIST    */
+  LGLSXP   /* LINEAR  */
 };
 
-static R_NativePrimitiveArgType idsfft_t[14] = {
-  INTSXP,  /* MD,   */
-  INTSXP,  /* NCP,  */
-  INTSXP,  /* NDP,  */
-  REALSXP, /* XD,   */
-  REALSXP, /* YD,   */
-  REALSXP, /* ZD,   */
-  INTSXP,  /* NXI,  */
-  INTSXP,  /* NYI,  */
-  REALSXP, /* XI,   */
-  REALSXP, /* YI,   */
-  REALSXP, /* ZI,   */
-  INTSXP,  /* IWK,  */
-  REALSXP, /* WK,   */
-  LGLSXP   /* MISSI */
-};
-
-static R_NativePrimitiveArgType sdsf3p_t[17] = {
+static R_NativePrimitiveArgType sdsf3p_t[18] = {
   INTSXP,  /* MD,     */
   INTSXP,  /* NDP,    */
   REALSXP, /* XD,     */
@@ -108,9 +78,11 @@ static R_NativePrimitiveArgType sdsf3p_t[17] = {
   LGLSXP,  /* EXTRPI, */
   INTSXP,  /* NEAR,   */
   INTSXP,  /* NEXT,   */
-  REALSXP  /* DIST    */
+  REALSXP, /* DIST    */
+  LGLSXP   /* LINEAR  */
 };
 
+/* ACM 697: */
 static R_NativePrimitiveArgType uvip3p_t[8] = {
   INTSXP,  /* NP, */
   INTSXP,  /* ND, */
@@ -122,6 +94,7 @@ static R_NativePrimitiveArgType uvip3p_t[8] = {
   INTSXP   /* ERR */
 };
 
+/* ACM 433: */
 static R_NativePrimitiveArgType intrpl_t[7] = {
   INTSXP,  /* L,  */
   REALSXP, /* X,  */
@@ -132,21 +105,34 @@ static R_NativePrimitiveArgType intrpl_t[7] = {
   INTSXP   /* ERR */
 };
 
+/* A. Gebhardt, no ACM code: */
+static R_NativePrimitiveArgType biliip_t[9] = {
+  REALSXP, /* X0,  */
+  REALSXP, /* Y0,  */
+  REALSXP, /* Z0,  */
+  INTSXP,  /* N0,  */
+  REALSXP, /* X,   */
+  REALSXP, /* Y,   */
+  REALSXP, /* Z,   */
+  INTSXP,  /* NX,  */
+  INTSXP   /* NY   */
+};
+
+
 static R_FortranMethodDef fortranMethods[] = {
-  {"idbvip", (DL_FUNC) &F77_SUB(idbvip), 13, idbvip_t}, /* interpp.old */
-  {"sdbi3p", (DL_FUNC) &F77_SUB(sdbi3p), 16, sdbi3p_t}, /* interpp.new */
-  {"idsfft", (DL_FUNC) &F77_SUB(idsfft), 14, idsfft_t}, /* interp.old  */
-  {"sdsf3p", (DL_FUNC) &F77_SUB(sdsf3p), 17, sdsf3p_t}, /* interp.new  */
-  {"uvip3p", (DL_FUNC) &F77_SUB(uvip3p), 8, uvip3p_t},  /* aspline     */
-  {"intrpl", (DL_FUNC) &F77_SUB(intrpl), 7, intrpl_t},  /* aspline     */
+  {"sdbi3p", (DL_FUNC) &F77_SUB(sdbi3p), 17, sdbi3p_t}, /* interpp     */
+  {"sdsf3p", (DL_FUNC) &F77_SUB(sdsf3p), 18, sdsf3p_t}, /* interp      */
+  {"uvip3p", (DL_FUNC) &F77_SUB(uvip3p), 8,  uvip3p_t}, /* aspline     */
+  {"intrpl", (DL_FUNC) &F77_SUB(intrpl), 7,  intrpl_t}, /* aspline     */
   {"rgbi3p", (DL_FUNC) &F77_SUB(rgbi3p), 12, rgbi3p_t}, /* bicubic     */
+  {"biliip", (DL_FUNC) &F77_SUB(biliip), 9,  biliip_t}, /* bilinear    */
   {NULL, NULL, 0}
 };
 
 void
 R_init_akima(DllInfo *info)
 {
-  R_registerRoutines(info, 
-		     NULL /*cMethods*/, NULL /*callMethods*/, 
+  R_registerRoutines(info,
+		     NULL /*cMethods*/, NULL /*callMethods*/,
 		     fortranMethods, NULL/*externalMethods*/);
 }
